@@ -10,17 +10,7 @@ use Log::Dispatch::Output;
 use base qw( Log::Dispatch::Output );
 use fields qw( stderr );
 
-    # This is a dirty trick for testing: Keep track
-    # of the entire object population. So we'll 
-    # be able to access the buffers even if the
-    # objects are created behind our back -- as
-    # long as we remember the order in which
-    # they've been created:
-    # $Log::Log4perl::TestBuffer::POPULATION[0] is
-    # the first one etc.
-    # The DESTROY method below cleans up afterwards.
-
-our @POPULATION = ();
+our %POPULATION = ();
 
 ##################################################
 sub new {
@@ -35,7 +25,7 @@ sub new {
     $self->{stderr} = exists $params{stderr} ? $params{stderr} : 1;
     $self->{buffer} = "";
 
-    push @POPULATION, $self;
+    $POPULATION{$self->name} = $self;
 
     return $self;
 }
@@ -66,7 +56,7 @@ sub reset {
 ##################################################
     my($self) = @_;
 
-    @POPULATION = ();
+    %POPULATION = ();
     $self->{buffer} = "";
 }
 
@@ -77,7 +67,23 @@ sub DESTROY {
 
     return unless defined $self;
 
-    @POPULATION = grep { defined $_ && $_ != $self } @POPULATION;
+    delete $POPULATION{$self->name};
+}
+
+##################################################
+sub by_name {   
+##################################################
+    my($self, $name) = @_;
+
+    # Return a TestBuffer by appender name. This is useful if
+    # test buffers are created behind our back (e.g. via the
+    # Log4perl config file) and later on we want to 
+    # retrieve an instance to query its content.
+
+    die "No name given"  unless defined $name;
+
+    return $POPULATION{$name};
+
 }
 
 1;
